@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of urlwatch (https://thp.io/2008/urlwatch/).
-# Copyright (c) 2008-2016 Thomas Perl <thp.io/about>
+# Copyright (c) 2008-2018 Thomas Perl <m@thp.io>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -50,7 +50,7 @@ class Mailer(object):
         raise NotImplementedError
 
     def msg_plain(self, from_email, to_email, subject, body):
-        msg = email.mime.text.MIMEText(body, 'plain', 'utf_8')
+        msg = email.mime.text.MIMEText(body, 'plain', 'utf-8')
         msg['Subject'] = subject
         msg['From'] = from_email
         msg['To'] = to_email
@@ -65,15 +65,16 @@ class Mailer(object):
         msg['To'] = to_email
         msg['Date'] = email.utils.formatdate()
 
-        msg.attach(email.mime.text.MIMEText(body_text, 'plain', 'utf_8'))
-        msg.attach(email.mime.text.MIMEText(body_html, 'html', 'utf_8'))
+        msg.attach(email.mime.text.MIMEText(body_text, 'plain', 'utf-8'))
+        msg.attach(email.mime.text.MIMEText(body_html, 'html', 'utf-8'))
 
         return msg
 
 
 class SMTPMailer(Mailer):
-    def __init__(self, smtp_server, smtp_port, tls, auth):
+    def __init__(self, smtp_user, smtp_server, smtp_port, tls, auth):
         self.smtp_server = smtp_server
+        self.smtp_user = smtp_user
         self.smtp_port = smtp_port
         self.tls = tls
         self.auth = auth
@@ -86,10 +87,10 @@ class SMTPMailer(Mailer):
             s.starttls()
 
         if self.auth and keyring is not None:
-            passwd = keyring.get_password(self.smtp_server, msg['From'])
+            passwd = keyring.get_password(self.smtp_server, self.smtp_user)
             if passwd is None:
-                raise ValueError('No password available in keyring for {}, {}'.format(self.smtp_server, msg['From']))
-            s.login(msg['From'], passwd)
+                raise ValueError('No password available in keyring for {}, {}'.format(self.smtp_server, self.smtp_user))
+            s.login(self.smtp_user, passwd)
 
         s.sendmail(msg['From'], [msg['To']], msg.as_string())
         s.quit()
